<p align="center">
<br><br><br>
<a href="https://github.com/mocha-dev/mocha"><img src="assets/mocha.png" alt="Mocha logo: Mocha is the Python Performance Profiler for Production" width="200px"></a>
<br><br>
</p>

<p align="center">
<b>Python Performance Profiling for Production</b><br>
<b>~ It's About Time ~</b>
</p>

# Mocha

Mocha is a Python performance profiler that can monitor your entire deployment in production, and makes results easy to aggregate and search through.

Bad code performance is often a result of lack of visibility, with [real world consequences](https://uxplanet.org/how-page-speed-affects-web-user-experience-83b6d6b1d7d7).

## Install 

```bash
pip install mocha-time
```
